@@ -19,7 +19,6 @@ GType retro_video_filter_get_type (void) G_GNUC_CONST;
  * @RETRO_VIDEO_FILTER_SMOOTH: a smooth but blurry video filer
  * @RETRO_VIDEO_FILTER_SHARP: a sharp video filter showing every pixel
  * @RETRO_VIDEO_FILTER_CRT: a video filter mimicking CRT screens
- * @RETRO_VIDEO_FILTER_COUNT: the number of video filters
  *
  * Represents the filters that can be applied to the video output.
  */
@@ -28,7 +27,6 @@ typedef enum
   RETRO_VIDEO_FILTER_SMOOTH,
   RETRO_VIDEO_FILTER_SHARP,
   RETRO_VIDEO_FILTER_CRT,
-  RETRO_VIDEO_FILTER_COUNT,
 } RetroVideoFilter;
 
 RetroVideoFilter retro_video_filter_from_string (const gchar *filter);
